==> apache-ratis-2.4.1-src.tar.gz: apache-ratis-2.4.1-src/ratis-test/src/test/java/org/apache/ratis/grpc/TestLeaderInstallSnapshot.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ratis.grpc;

import org.apache.ratis.InstallSnapshotFromLeaderTests;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

import java.util.Arrays;
import java.util.Collection;

@RunWith(Parameterized.class)
public class TestLeaderInstallSnapshot
extends InstallSnapshotFromLeaderTests<MiniRaftClusterWithGrpc>
implements MiniRaftClusterWithGrpc.FactoryGet {

    public TestLeaderInstallSnapshot(Boolean separateHeartbeat) {
        GrpcConfigKeys.Server.setHeartbeatChannel(getProperties(), separateHeartbeat);
    }

    @Parameterized.Parameters
    public static Collection<Boolean[]> data() {
        return Arrays.asList((new Boolean[][] {{Boolean.FALSE}, {Boolean.TRUE}}));
    }
}

==> apache-ratis-3.1.0-src.tar.gz: apache-ratis-3.1.0-src/ratis-test/src/test/java/org/apache/ratis/grpc/TestLeaderInstallSnapshot.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ratis.grpc;

import org.apache.ratis.InstallSnapshotFromLeaderTests;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.MethodSource;

import java.util.Arrays;
import java.util.Collection;

public class TestLeaderInstallSnapshot
extends InstallSnapshotFromLeaderTests<MiniRaftClusterWithGrpc>
implements MiniRaftClusterWithGrpc.FactoryGet {

    public static Collection<Boolean[]> data() {
        return Arrays.asList((new Boolean[][] {{Boolean.FALSE}, {Boolean.TRUE}}));
    }

    @ParameterizedTest
    @MethodSource("data")
    public void testMultiFileInstallSnapshot(Boolean separateHeartbeat) throws Exception {
        GrpcConfigKeys.Server.setHeartbeatChannel(getProperties(), separateHeartbeat);
        super.testMultiFileInstallSnapshot();
    }

    @ParameterizedTest
    @MethodSource("data")
    public void testSeparateSnapshotInstallPath(Boolean separateHeartbeat) throws Exception {
        GrpcConfigKeys.Server.setHeartbeatChannel(getProperties(), separateHeartbeat);
        super.testSeparateSnapshotInstallPath();
    }

    @ParameterizedTest
    @MethodSource("data")
    public void testInstallSnapshotLeaderSwitch(Boolean separateHeartbeat) throws Exception {
        GrpcConfigKeys.Server.setHeartbeatChannel(getProperties(), separateHeartbeat);
        super.testInstallSnapshotLeaderSwitch();
    }
}
